###############################################################################
# $Id: 1101404_9901225_1.2.pri,v 1.1 2012/09/07 00:55:01 ahan Exp $
#
# Name:      MC7700 PRI file
#
# Purpose:   Rogers Generic DIP configuration
#
# Copyright: Sierra Wireless, 2002-2012. 
#            This document contains information which is proprietary and confidential to Sierra Wireless, Inc. Disclosure to persons
#            other than the officers, employees, agents, or subcontractors of the Company or licensee of this document without the prior 
#            written permission of Sierra Wireless, Inc. is strictly prohibited.
#
# Note:
#            Customization Form Version: 1.0
#            PRI Template Version      : B-13
#
#            All commands listed in this file are Mandatory except for 
#            the ones explicitly stated as optional.
#                                                                             
###############################################################################

###############################################################################
####### Basic identification information - These fields are MANDATORY #########
###############################################################################
INFO:REV=1.0
INFO:SKU=9901726
INFO:CUSTOMER=MC7710 Generic DIP
### vve: MODEMTYPE must match the current model string!
INFO:MODEMTYPE=MC7710

###############################################################################
####### Initial AT Commands - Do not Modify ###################################
###############################################################################

############## Disable FTM ################
# Applies to: All
#
# Note: For all 6275 fw, and 6280 FW older than 1.0.0.17, 
#       use SERIAL:AT!NV=453,00 instead.
#
INITIAL:AT!NVOEM=FTM_MODE,00

############## Go offline #################
# Applies to: All
#
# Description: Devices should be in Offline mode when NV updated
#
INITIAL:AT!DAOFFLINE

############## Backup RF Cal Data #########
# Applies to: All
#
# vve: optional
INITIAL:AT!NVBACKUP=0

############## Initially Disable SWOC ######
# Applies to: ALL
#
# Description: Make sure SWOC is disabled before FW download
#
# vve: optional - disabled by default
INITIAL:AT!CUSTOM="SWOCENABLE",0

############## SIM Presence ###############
# Applies to: Not applicable to 6280, 7200R3
#
# SWI Ref: none
#
# Description: This command returns errors if there is a SIM card inserted
#    into the modem when programming PRI. It's needed to ensure modems are
#    not shipped with a SIM installed.
#
# Usage: INITIAL:AT!SIMNOTINSTALLED?
#
# vve: optional
INITIAL:AT!SIMNOTINSTALLED?

############## micro-SD Presence ##########
# Applies to: Not applicable to 6280, 7200R3
#
# SWI Ref: none
#
# Description: This command returns errors if there is a SD card inserted
#    into the modem when programming PRI. It's needed to ensure modems are
#    not shipped with a micro-SD installed.
#
# Usage: INITIAL:AT!SDNOTINSTALLED?
#
# vve: optional
INITIAL:AT!SDNOTINSTALLED?

###############################################################################
####### Firmware Download #####################################################
###############################################################################

############## TAC Code ###################
# Applies to: All
#
# SWI Ref: S005
#
# Description: TAC is specific to each MiniCard variant and possible
#     customer/OEM. Since some of older version of BOOT does not
#     support TAC setting, this command is always executed after 
#     firmware download even if it's defined before it.
#
#OPTION:TAC=01262600

############## TAC Code #####################
# Applies to: All
# 
#OPTION:VERIFYTAC=YES

############## Skip IMEI Check #####################
# Applies to: RCT 2.0.0.11
# 
# Description: This option to disable IMEI checking for RMA PRI
#
# Usage: SKIPIMEICHECK=<value>
#              value = YES to skip IMEI checking
#
# vve: mandatory!
OPTION:SKIPIMEICHECK=YES

############## Skip IMEI Write #####################
# Applies to: RCT 2.2.x.x
# 
# Description: This option to Skip IMEI write. OEM will responsible to write IMEI
#              IMEI will still create according to TAC and SNR and display inside output file
#              Modem will have factory default IMEI when configuration completed
#
# Usage: SKIPIMEIWRITE=<value>
#              value = YES to skip IMEI writing
#
OPTION:SKIPIMEIWRITE=YES	 

############## Product ID Check ###################
# Applies to: All
#
# SWI Ref: N/A
#
# Description: Product ID is specific to each carrier and RF calibration.
#              This option to enable checking of product ID in FSN
#
#              Hardware version usually contains 2 digits
#
#OPTION:PROID=35

############## ICCID #####################
# 
# Description: Factory option to log SIM Card S/N to export file. 
#              ICCID is logged to field 25 and 
#              SIM Presence option must be turned off
#OPTION:LOG_ICCID=YES

############## Test History Checking ########
# Applies to: All
#             However only BCT tool 3.3.1.2 and later will check it
#
# Description: This option to supply a pattern for Test History
#     checking. xx means don't care, bits marked as such are ignored.
#
# Usage: OPTION:TESTHISTORY=<value>
#     value = 01,01,01,01,01 for AirCards
#             01,01,01,01,xx for Compass/USB
#             01,01,01,xx,xx for MiniCards
#             01,01,01,xx,01 for MiniCards (LTE)
#             01,01,01,01,01 for AirCards (LTE)
#             PPPPP          for Icera's Modem
#
OPTION:TESTHISTORY=01,01,01,xx,01

############## Chipset ######################
# Applies to: ALL
#
# Usage: OPTION:CHIPSET=<value>
#     value = QUALCOMM for Qualcomm Modem
#             ICERA for Icera Modem
OPTION:CHIPSET=QUALCOMM

############## Sanity Check #################
# Applies to: RCT version x.x.x.x
#
# Description: Sanity Check is done at the end of pri'ing. It includes 
#     verification of test history, and IMEI based on its expected
#     value.
#
# Usage: OPTION:SANITY_CHECK=<value>
#     value = NO, does not perform sanity check, for RMA PRIs 
#             (where IMEI will be rewritten to default value)
#     value = YES, perform sanity check, for all other PRIs
#
#OPTION:SANITY_CHECK=YES

############## Type #######################
# Applies to: All
#
# Usage: DOWNLOAD:TYPE=<type>
#     type = BUT      for AirCards
#     type = MINICARD for MiniCards
#
#DOWNLOAD:TYPE=MINICARD

############ Update Tool ##################
# Applies to: ALL
#
# Usage: DOWNLOAD:TOOL=<value>
#     value = BinUpdater.exe for Qualcomm Modem
#             downloader.exe for Icera Modem
#             fdt.exe for Fast firmware updater
#             
##DOWNLOAD:TOOL=BinUpdater.exe

############## BUT Part Number ############
# Applies to: BCT tool 3.3.0.5 and later
#
# Description: This allows BCT to find the binupdater tool in a 
#     subdirectory of C:\AC710\<BUT_PART_NUMBER> so that multiple
#     versions of BUT can be kept separately
#
# Usage: DOWNLOAD:BUT_PART_NUMBER=<value>
#     value = BUT part number for this SKU#     
#     value = 9992842 for BUT 1.6.8.3
#     value = 9992971 for BUT 1.6.9.4
#     value = 9993130 for BUT 1.6.9.6
#     value = 9993285 for BUT 1.6.10.0
#     value = 9900209 for BUT 10.0.0.6
#     value = 9900334 for BUT 10.9.0.1
#     value = 9900635 for BUT 10.11.0.0
#     value = 9900783 for BUT 11.1.1102.1
#
##DOWNLOAD:BUT_PART_NUMBER=9900978

############## BUT Options ################
# Applies to: BCT tool 3.3.0.7 and later
#
# Usage: DOWNLOAD:BUT_OPTIONS=<value>
#     value = -p for MP download
#             -c for compact mode, always turned on by default
#             -timeout for RCT to wait after firmware download completed
#             for other values, type "binupdater.exe -h" to get a full list
#
#DOWNLOAD:BUT_OPTIONS=-p
##DOWNLOAD:BUT_OPTIONS=-p

############## Bootloader, App ,SWoC, CIQC and SUPL cert ###
# Applies to: All
#
# SWI Ref: G001 & G002 & S006 & G132
#
# Usage: DOWNLOAD:BOOT=<absolute path and file name>
#        DOWNLOAD:APPL=<absolute path and file name>
#        DOWNLOAD:SWOC=<absolute path and file name>
#        DOWNLOAD:CIQC=<absolute path and file name>
#        DOWNLOAD:SUPL=<absolute path and file name>
#        DOWNLOAD:WEBU=<absolute path and file name>
#        DOWNLOAD:SPKG=<absolute path and file name>
#
#DOWNLOAD:CIQC=C:\RCT\FIRMWARE\SCAQWBZ_BOOT_MC_SWI9200X.03.00.09.00.cwe
#DOWNLOAD:BOOT=C:\RCT\FIRMWARE\SCAQWBZ_BOOT_MC_SWI9200X.03.05.14.00.cwe
#DOWNLOAD:APPL=C:\RCT\FIRMWARE\SCAQWBZ_SWI9200X.03.05.14.00.cwe
#DOWNLOAD:SWOC=C:\Sierra\mobileconnect.cwe

############## USBD #######################
# Applies to: All
#
# SWI Ref: G113
#
# Description: If the customer wants to use default USB descriptor,
#     you may need to download one here, or use what's on the modem.
#     If the customer wants to customize USB descriptor, please see
#     G114, G115, G116, G117 and G118 in General Settings section.
#
# Usage: DOWNLOAD:USBD=<path and file name>
#        path name should be an absolute path.
#

###############################################################################
####### Final AT Commands - Do not Modify #####################################
###############################################################################

############## Delete All Profiles ########
# Applies to: All
#
# Note: For all 6280 FW older than H2.0.8.8, OPTION:DELETEPROFILE=ALL should be used to 
#       delete profile. 
#       Using OPTION:DELETEPROFILE=ALL, RCT will use build in AT command to delete all profiles
#
#SERIAL:AT!SCPROFDEL

############## Disable FTM ################
# Applies to: All
#
# Note: For all 6275 fw, and 6280 FW older than 1.0.0.17, 
#       use SERIAL:AT!NV=453,00 instead.
#
SERIAL:AT!NVOEM=FTM_MODE,00

############## Go Offline #################
# Applies to: All
#
SERIAL:AT!DAOFFLINE

############## Clear FOTA Partition ##############
# Applies to: All
#
#SERIAL:AT!IDSCLEARSTATE

############## NV defaulting ##############
# Applies to: All
#
# Description: this clears all old customizations (ala AT!CUSTRST)
#
#SERIAL:AT!NVBACKUPCHECK
#SERIAL:AT!NVBACKUPCHECK?
#SERIAL:AT!NVDEF
#SERIAL:AT!NVRESTORE=0
#SERIAL:AT!NVRESTOREPROTECTED

###############################################################################
####### Carrier Customizations - General Settings #############################
###############################################################################

############## PRI & Version ##############
# Applies to: Not applicable to 6280 FW older than H1.1.5.1
#
# SWI Ref: S003 & S004
#
# Usage: SERIAL:AT!PRIID=<pri_pn>,<pri_ver>
#     pri_pn  = 7 Digit ASCII test used to store the PRI part number
#     pri_ver = 4 Digit PRI Revision in format AA.BB, 
#               e.g. version1.3 is written as 0103
#
# vve: optional
#SERIAL:AT!PRIID=9901726,0100

############## Enable Micro-SD ############
# Applies to: Not applicable to 6280, 7200R3, or 7200A FW older than J0.0.3.6
#             Applies to devices with micro-SD capability (e.g. Compass885)
#
# SWI Ref: G035
#
# Description: This command enables Micro-SD operation on modems. It has
#     to be run because it may have been turned off during factory testing.
#
# Usage: SERIAL:AT!CUSTOM="USBMSENABLE",<value>
#     value = 0 - Disable MicroSD
#             1 - Enable MicroSD through USB as mass storage device
#             4 - Enable MicroSD file sharing for hotspot
#
#SERIAL:AT!CUSTOM="USBMSENABLE",0

############## Product Name ###############
# Applies to: Not applicable to 6280, 7201/A, 6290 or 8200 FW older than M2.0.6.4
#
# SWI Ref: G125
# 
# Description: This command is used to set the product name. If product name is not set, 
#              hardcoded string will be displayed based on device hardware ID.
#
# Usage: SERIAL:AT!NVPRODUCTNAME="<value>"
#             value = Max. 15 character string
#
# vve: new model name to set
#SERIAL:AT!NVPRODUCTNAME="MC7710"

############## GPRS Class #################
# Applies to: All
#
# SWI Ref: G003
#
# Usage: SERIAL:AT!NVOEM=MSCLASS,<value>
#     value = class in hex form, 0C is 12
#
# Note: For all 6275 fw, and 6280 FW older than 1.0.0.17, 
#       use SERIAL:AT!NV=911,0C instead.
#
# Note: For 6290/6246 fw, or newer chipset
#       All AT&T's minicard SKU required this to set to Class 10, 0A
#
#SERIAL:AT!NVOEM=GMSCLASS,0A

############## Set EDGE Class #############
# Applies to: All
#
# SWI Ref: G124
#
# Usage: SERIAL:AT!NVOEM=EMSCLASS,0C
#      value = class in hex form, 0C is 12
#
# Note: For all 6275 fw, and 6280 FW older than 1.0.0.17, 
#       use SERIAL:AT!NV=2509,0C instead.
#
#SERIAL:AT!NVOEM=EMSCLASS,0C

############## Ciphering and Integrity ####
# Applies to: All
#
# Usage: SERIAL:AT!GCIPHER=<value>
#     value = 0 ciphering disabled, integrity disabled
#     value = 1 ciphering enabled, integrity disabled
#     value = 2 ciphering enabled, integrity enabled
#     value = 3 ciphering disabled, integrity enabled
#
#SERIAL:AT!GCIPHER=2

############## PS and CS Service ##########
# Applies to: All
# 
# SWI Ref: G004 & G005, see CSD
#
# Description: used to be SERIAL:AT!NV=850,00,02,00
#
# Usage: SERIAL:AT!SELMODE=<value>
#     value = 0 CS only, will not do PS attach on start up, but
#               will do PS attach and connect PDP context when 
#               user clicks "CONNECT". This will affectively create
#               "disable GPRS attach on start up".
#     value = 1 PS only, will not do CS attach on start up, but
#               will do CS attach and connect call when user tries
#               to make a voice call, provided CSD is enabled (see CSDOFF).
#     value = 2 CS and PS
#
#SERIAL:AT!SELMODE=2

############## CSD ########################
# Applies to: Not applicable to 6280 FW older than 1.1.8/9.8 or older than 2.0.3.2
#
# SWI Ref: G004 & G005, see PS and CS Service
#
# Description: This function is only useful when SELMODE=1. 
#     When in PS only mode, enable CSD will let modem attach
#     in CS domain when making calls, disable CSD will not 
#     let modem attach in CS domain any time.
#
# Usage: SERIAL:AT!CUSTOM="CSDOFF",<value>
#     value = 0 CSD enabled (default)
#     value = 1 CSD disabled
#
#SERIAL:AT!CUSTOM="CSDOFF",0

############## Voice ######################
# Applies to: All
#
# SWI Ref: G006
#
# Usage: SERIAL:AT!CUSTOM="ISVOICEN",<value>
#     value = 0 disabled (default)
#     value = 1 enabled
#     value = 2 disabled on CnS and AT (new FW only, see below)
#
# Note: When this feature is disabled (value 0), it only means:
#       - no voice will be set in CNS_AVAILABLE_FEATURES object
#       - headset indication will not be sent to host
#       - CNS notifications related to voice features will not be
#         sent to the host
#       - voice calls CAN still be made via AT command interface
#
#       When this feature is disabled (value 2), it means the above, except:
#       - voice calls CANNOT be made/received via AT command interface
#       - this applies to new FW only (6280 FW H2.0.6.0, H1.1.8/9.18 and newer;
#                                      7200R3 FW F1.0.0.3, F1.0.1.2 and newer;
#                                      7200A, 6290 FW all)
#
#SERIAL:AT!CUSTOM="ISVOICEN",2

############## Ignore Voice Paging ########
# Applies to: Not applicable to 6280, 7200A, 6290 FW, or
#                               7200R3 FW older than F1.2.3.13
#
# SWI Ref: G036
#
# Description: When this feature is enabled, the modem does not process
#     or respond to 3G Voice Paging requests from the network. 2G paging
#     requests will still be responded to as there is no way to
#     differentiate voice pages from other types in 2G.
#
# Usage: SERIAL:AT!CUSTOM="CSVOICEREJECT",<value>
#     value = 0 disabled (default)
#     value = 1 enabled (Do not process pages) 
#     value = 2 enabled (Accept processing, but return reject cause) 
#     Note: CSVOICEREJECT = 2 allows to accept CS paging loopback test
#
#SERIAL:AT!CUSTOM="CSVOICEREJECT",0

############## Set Protocol ###############
# Applies to: All
# 
# SWI Ref: G007, G008, G009, G010, see HSDPA Category and HSUPA Category
#
# Description: Used to set the protocol version for the air 
#     interface, and the interfaces to SGSN and MSC. 
#
# Note: Always leave <sgsn> and <msc> to 1 when using 7200R3 F1.2 FW
#     and later, 7200A, 6290 FW all. For those FW versions, use !NASREL to 
#     configure SGSN and MSC protocol version instead.
#
# Usage: SERIAL:AT!REL=<proto>,<sgsn>,<msc>
#     proto = 0 Release 99
#     proto = 1 Release 5 
#     proto = 2 Release 6
#     proto = 3 Release 7
#     proto = 4 Release 8
#     sgsn = 0 Release 97
#     sgsn = 1 Release 99 (default)
#     sgsn = 2 dynamic - use what is broadcasted by network
#     sgsn = 3 Release 5 (only for FWs that do not support NASREL)
#     msc = 0 Release 97
#     msc = 1 Release 99 (default)
#     msc = 2 dynamic - use what is broadcasted by network
#     msc = 3 Release 5 (only for FWs that do not support NASREL)
#
# Example: For UMTS only (non-HS): SERIAL:AT!REL=0,1,1
# Example: For HSDPA: SERIAL:AT!REL=1,1,1
# Example: For HSUPA: SERIAL:AT!REL=2,1,1
#
#SERIAL:AT!REL=4,1,1

############## Set NAS Protocol ###########
# Applies to: Not applicable to 6280 FW, or 7200R3 FW older than F1.2
# 
# SWI Ref: G009, G010
#
# Description: Used to set the NAS layer protocol version (used in the 
#      interfaces to SGSN and MSC). This command is used in place of the
#      second and third parameters of !REL for applicable firmware. If
#      customer selects "Default", this command can be commented out.
#
# Usage: SERIAL:AT!NASREL=<value>
#      value = 0 Release 99 (default for 7200R3)
#      value = 1 Release 5 (default for 7200A and 6290)
#      value = 2 Release 6
#      value = 3 Release 7
#      value = 4 Release 8
#
#SERIAL:AT!NASREL=0

############## Compress Mode with DPA/UPA #
# Applies to: Not applicable to 6280 FW, or 7200R3 FW older than F1.2
#             
# SWI Ref: G032, G037
# 
# Usage: SERIAL:AT!CMEN=<dpa>[,<upa>]
#     dpa = 0 CM in HSDPA disabled
#     dpa = 1 CM in HSDPA enabled (default)
#     upa = 0 CM in HSUPA disabled 
#     upa = 1 CM in HSUPA enabled (default)
#     upa = 2 CM in HSUPA enabled but don't broadcast
#
#SERIAL:AT!CMEN=1,1

############## HSDPA Category ############
# Applies to: Not applicable to 6280 FW older than H2.0.1.0,
#             Applies only if HSDPA is enabled (via AT!REL)
#
# SWI Ref: G007
#
# Usage: SERIAL:AT!HSDCAT=<value>
#     value = 12, Category 12, all 6275
#     value = 6 , Category 6, 6280 H1 release, 7200R3 D release, all 6270
#     value = 8 , Category 8, 6280 H2 release, 7200R3 F release, 7200A, 6290 all
#     value = 10, Category 10, all 6200
#     value = 14, Category 14, all 8200
#     value = 24, Category 24, all 8220
#
# Note: unlike most customization items in this file, please leave this
#     command commented out unless you're certain the customer needs to
#     change this field. There should be no such need under normal 
#     circumstances.
#
#SERIAL:AT!HSDCAT=x
#SERIAL:AT!HSDCAT=24

############## HSUPA Category ############
# Applies to: Not applicable to 6280 FW,
#             Applies only if HSUPA is enabled (via AT!REL)
# 
# SWI Ref: G008
#
# Usage: SERIAL:AT!HSUCAT=<value>
#     value = 3, Category 3
#     value = 5, Category 5
#     value = 6, Category 6
#     value = 7, Category 7
#
# Note: unlike most customization items in this file, please leave this
#     command commented out unless you're certain the customer needs to
#     change this field. There should be no such need under normal 
#     circumstances.
#
#SERIAL:AT!HSUCAT=x
#SERIAL:AT!HSUCAT=6

############## Scanning Algorithm #########
# Applies to: All
#     value = 6 is not supported by 6280 FW older than H1.1.8/9.12 or older than H2.0.3.6
#     value = 4 is not supported by 6275 FW
#
# SWI Ref: G102 & G103
#
# Usage: SERIAL:AT!CUSTOM="PRLREGION",<value>
#     value = 1 Europe/Rest of the World
#     value = 2 North America
#     value = 3 Australia
#     value = 4 Japan
#     value = 6 H3G, W2100, G900/1800
#
#SERIAL:AT!CUSTOM="PRLREGION",1

############## RAT Selection ##############
# Applies to: All 
# 
# SWI Ref: G133
# 
# Descritpion: To set the current RAT and RAT Acquisition Order preference of the modem
#
# Usage: SERIAL:AT!SELRAT=<value>
#     value = 00 Automatic
#     value = 01 UMTS 3G Only
#     value = 02 GSM 2G Only
#     value = 03 UMTS 3G Preferred
#     value = 04 GSM 2G Preferred
#
#SERIAL:AT!SELRAT=00
#SERIAL:AT!SELRAT=00
############## Band Settings ##############
# Applies to: All
#
# SWI Ref: G100 
# 
# Usage: SERIAL:AT!BAND=<value>
#     value =  0 All bands (Auto)
#     value =  1 WCDMA 2100
#     value =  2 WCDMA 800/1900
#     value =  3 GSM 900/1800
#     value =  4 GSM 850/1900
#     value =  5 GSM ALL
#     value =  6 WCDMA 2100 GSM 900/1800
#     value =  7 WCDMA 800/1900 GSM 850/1900
# 
# Note: We should always set AT!BANDDEF and also two band selections must be written
#       this to ensure BAND is set on the modem
# Note: If more specific tuning is required, please see below "Custom Band Selection"
#
# Example: SERIAL:AT!BAND=0
#SERIAL:AT!BAND=0
#SERIAL:AT!BANDDEF
#SERIAL:AT!BAND=1
#SERIAL:AT!BAND=0

############## Custom Band Selections ##############
# Applies to: Applicable only to 8220 & 9200
# 
# SWI Ref: G129 & G130 & G131
#
# Description: Reverts to default band selections
# Usage: SERIAL:AT!BANDDEF
#
# Description: Customize band selection
# Usage: SERIAL:AT!BAND=<index>,"<name>",<value>,[,<lte_mask>]
#     <index>    = Band index
#     <name>     = Custom name
#     <value>    = a combination of each band mask bit:
#                    0000000000000080 - G1800
#                    0000000000000300 - G900 (EGSM + GSM)
#                    0000000000080000 - G850
#                    0000000000200000 - G1900
#                    0000000000400000 - W2100
#                    0000000000800000 - W1900
#                    0000000004000000 - W850
#                    0000000008000000 - W800
#                    0002000000000000 - W900
#     <ite_mask> = a combination of each band mask bit:
#                    0000000000000001 - B1
#                    0000000000000002 - B2
#                    ...
#                    0000004000000000 - B39
#                    0000008000000000 - B40
#
# Example: SERIAL:AT!BANDDEF
# Example: SERIAL:AT!BAND=4,"Custom Name", 000000000C000000
# Example: SERIAL:AT!BAND=4,"", 0
#SERIAL:AT!BAND=4,"",0

############## USBD Composite #############
# Applies to: Not applicable to 6280, 7200R3 and 6290 K2.0 FW
#             Applies to MiniCards Only
#             Applies only if customer wishes to customize USBD (G113)
#
# SWI Ref: G114
#
# Description: It sets the USB device configuration to Composite 
#     Mode (default) or Non Composite Mode.
#
# Usage: SERIAL:AT!UDCOMP=<value>
#     value = 0 Composite (default)
#     value = 1 Non Composite
#
#SERIAL:AT!UDCOMP=0

############## USBD PID ###################
# Applies to: Not applicable to 6280, 7200R3 FW
#             Applies only if customer wishes to customize USBD (G113)
#
# SWI Ref: G116
#
# Description: It sets the product ID in USB Descriptor.
#              To enable Direct IP set UDPID to 68A3
#
# Usage: SERIAL:AT!UDPID=<value>
#     value = PID in hex ASCII
#
#SERIAL:AT!UDPID=68A3

############## USBD VID ###################
# Applies to: Not applicable to 6280, 7200R3 FW
#             Applies only if customer wishes to customize USBD (G113)
#
# SWI Ref: G115
#
# Description: It sets the vendor ID in USB Descriptor.
#
# Usage: SERIAL:AT!UDVID=<value>
#     value = VID in hex ASCII
#
#SERIAL:AT!UDVID=1199

############## USBD Manufacturer ##########
# Applies to: Not applicable to 6280, 7200R3 FW
#             Applies only if customer wishes to customize USBD (G113)
#
# SWI Ref: G117
#
# Description: It sets the Product Manufacturer string in USB Descriptor.
#
# Usage: SERIAL:AT!UDMANUFACTURER=<value>
#     value = manufacturer string in ASCII
#
#SERIAL:AT!UDMANUFACTURER="Sierra Wireless, Incorporated"

############## USBD Product ###############
# Applies to: Not applicable to 6280, 7200R3 FW
#             Applies only if customer wishes to customize USBD (G113)
#
# SWI Ref: G118
#
# Description: It sets the Product Name string in USB Descriptor.
#
# Usage: SERIAL:AT!UDPRODUCT=<value>
#     value = product name string in ASCII
#
#SERIAL:AT!UDPRODUCT="HSPA Modem"

############## USB Interface Configuration #######
# Applies to: Not applicable to 6280, 7201/A, 8200 M2.0 older then Release 1
#
# SWI Ref: G123
#
# Description: To set USB interface configuration thus allowing a device to have 
#              multiple USB compositions. 
#
# Usage: AT!UDUSBCOMP=<value>
#     value = 0 HIP DM NMEA AT MDM1 MDM2 MDM3 MS (Traditional/Direct IP Interface)
#     value = 1 HIP DM NMEA AT MDM1 MS (Not Supported) 
#     value = 2 HIP DM NMEA AT NIC1 MS (Direct IP Interface only)
#     value = 3 HIP DM NMEA AT MDM1 NIC1 MS (Direct IP Interface only)
#     value = 4 HIP DM NMEA AT NIC1 NIC2 NIC3 (Direct IP Interface only)
# 
#SERIAL:AT!UDUSBCOMP=0

############## Preferred Channel Acquistion ####
# Applies to: All 
#
# SWI Ref: G106
#
# Description: This sets the channels in the WCDMA Acquisition
#     Database, i.e. the channels got scanned first. Up to 10 channels
#     numbers can be defined. Always run =0 to clear the list before
#     defining any preferred channels.
#
# Usage: SERIAL:AT!ACQCHAN=<channel number>,<mcc>,<mnc>
#     channel number = 0 to clear the list, need to be run first
#     channel number = WCDMA channel number
#     mcc = MCC
#     mnc = MNC
#
# for MDM9200 X1.1.2.1 or later
#
# Description: This sets the channels in the WCDMA and LTE Acquisition
#     Database, i.e. the channels got scanned first. Up to 10 channels
#     numbers can be defined. Always run =0 to clear the list before
#     defining any preferred channels.
#
# Usage: SERIAL:AT!ACQCHAN=<RAT>,<channel number>,<mcc>,<mnc>
#     
#     RAT = 0-GSM; 1-WCDMA; 2-LTE
#     
#SERIAL:AT!ACQCHAN=0

############## PCSC and Auth Commands #####
# Applies to: All
#
# SWI Ref: G011 & G012 & G120
#
# Usage: SERIAL:AT!CUSTOM ="PCSCDISABLE",<value>
#     bit 0: PCSC; bit 1: GSM Algorithm and Authenticate commands; bit 2: Display of IMSI
#     ( Set bit to disable function )
#     value = 0 All enabled (default)
#     value = 1 disable PCSC
#     value = 2 disable running GSM Algorithm and 
#               Authenticate commands through AT!AUTH,
#               AT+CSIM, PC/SC interface or SDK
#     value = 3 disable PCSC and Auth Commands
#     value = 4 disable display of IMSI
#     value = 5 disable PCSC
#               disable dispaly of IMSI
#     value = 6 disable running GSM Algorithm and Authenticate commands
#               disable display of IMSI
#     value = 7 All disabled
#
# Note: When PCSC interface is disabled, windows will not display PCSC 
#    device port.
#
#SERIAL:AT!CUSTOM="PCSCDISABLE",3

############## Roaming Indicator ##########
# Applies to: Watcher/API only
#
# SWI Ref: G015
#
# Description: Disables the display of the roaming icon in Watcher
#
# Usage: SERIAL:AT!CUSTOM="NOROAM",<value>
#     value = 0 displayed (default)
#     value = 1 not displayed
#
#SERIAL:AT!CUSTOM="NOROAM",0

############## SIM PUK Prompt #############
# Applies to: Watcher/API only 
#
# SWI Ref: G017
#
# Description: If the SIM PIN is locked and the user exceeds
#     the max number of retries trying to enter it, this option
#     will cause the user to be prompted for the SIM's PUK code. 
#
# Usage: SERIAL:AT!CUSTOM="PUKPRMPT",<value>
#     value = 0 disabled (default)
#     value = 1 enabled
#
#SERIAL:AT!CUSTOM="PUKPRMPT",1

############## STK basic support level ####
# Applies to: Watcher/API for SIM Tool Kit only
#
# SWI Ref: G018
#
# Description: Enables the SIM Toolkit menu item in Watcher
#
# Usage: SERIAL:AT!CUSTOM="STKUIEN",<value>
#     value = 0 STK UI Disabled (default)
#     value = 1 STK UI Enabled (via CNS)
#     value = 2 STK UI Enabled (via AT)
#
#SERIAL:AT!CUSTOM="STKUIEN",0

############## SMS MO domain ##############
# Applies to: Not applicable to 6280 FW older than H1.1.8/9.8
#
# SWI Ref: G019
#
# Usage: SERIAL:AT+CGSMS=<value>
#     value = 0 PS Domain
#     value = 1 CS Domain
#     value = 2 PS Preferred, use CS if PS is not available 
#     value = 3 CS Preferred, use PS is CS is not available (default)
#
#SERIAL:AT+CGSMS=3

############## Data Inactivity Timer ######
# Applies to: Not applicable to 6280 FW older than H1.1.8/9.12 or older than H2.0.3.6
# 
# SWI Ref: G021
#
# Description: This timer, a.k.a GPRS Inactivity Timer, is reset every
#     time there is PS data traffic. Background PLMN scan will not take
#     place until this timer is expired.
#
# Usage: SERIAL:AT!BPLMNTIMER=<value>
#     value = GPRS Inactivity Timer in seconds (default 45)
#
#SERIAL:AT!BPLMNTIMER=45

############## Revert to Auto Network Mode#
# Applies to: Not applicable to 6280 FW older than H1.1.8/9.12 or older than H2.0.3.6
# 
# SWI Ref: G022
#
# Description: Determines if UE should revert to Automatic Network mode 
#     after 60 seconds of Manual Network mode
#
# Usage: SERIAL:AT!CUSTOM="AUTONETWORKMODE",<value>
#     value = 0 Remain in Manual (default)
#     value = 1 Revert to Automatic
#     value = 2 Revert to Automatic, unless CS, PS, or CS+PS attached
#
#SERIAL:AT!CUSTOM="AUTONETWORKMODE",0

############## A5 Encryption ##############
# Applies to: All
#
# SWI Ref: G025
#
# Usage: SERIAL:AT!NVOEM=GSMA5ALG,<value>, where value is a bitmask
#     bit 0: A5/1; bit 1: A5/2; bit 2: A5/3
#     value = 01 A5/1 enabled, all others disabled (default)
#     value = 05 A5/1 enabled, A5/3 enabled (default for 6290, 8200)
#
# Note: For all 6275 fw, and 6280 FW older than 1.0.0.17, 
#       use SERIAL:AT!NV=553,<value> instead.
#
#       Currently AT&T is the only one needs A5/2 enabled, even this was
#       removed by AT&T in April 2007. However, their 6275 and 6280 will keep
#       A5/2 enabled, and 7200 and later products will disable it.
#
#       The value needs to be two characters. Do not remove the 0 in the front.
#
#SERIAL:AT!NVOEM=GSMA5ALG,01

############## GEA Encryption #############
# Applies to: Not applicable to 6280 FW, or 7200R3 FW older than F1.2
#
# SWI Ref: G033
#
# Usage: SERIAL:AT!NVOEM=GEAALG,<value>, where value is a bitmask
#     bit 0: GEA1; bit 1: GEA2; bit 2: GEA3
#     value = 01 GEA1 enabled
#     value = 03 GEA1 & GEA2 enabled 
#     value = 07 All enabled
#
# Note: The value needs to be two characters. Do not remove the 0 in the front.
#
#SERIAL:AT!NVOEM=GEAALG,03

############## DARP Setting ###############
# Applies to: Not applicable to 6280 FW, or 7200R3 FW older than F1.2
#
# SWI Ref: G034
#
# Description: This command tells the protocol stack to configure itself
#     for Downlink Advanced Receiver Performance (DARP) for Single-
#     Antenna Interference Cancellation (SAIC). Some devices may not 
#     support DARP, in which case this command is not supported.
#
# Note: Please leave this command commented out as it is not in the
#     customization form yet.
#
# Usage: SERIAL:AT!DARPEN=<value>
#     value = 0 disable SAIC/DARP
#     value = 1 enable SAIC/DARP (default)
#
#SERIAL:AT!DARPEN=1

############## HPPLMN Scan on foreign MCC #
# Applies to: All
#
# SWI Ref: G023
# 
# Usage: SERIAL:AT!CUSTOM="HPPLMNSCDIS",<value>
#     value = 0 enabled (default) HPPLMNSC
#     value = 1 disabled HPPLMNSC, for HP-Vodafone
#
#SERIAL:AT!CUSTOM="HPPLMNSCDIS",0

############## Enhanced Network Selection #
# Applies to: AT&T only
#
# SWI Ref: G024
#
# Description: Sets Enhanced Network Selection for AT&T, used 
#     to be SERIAL:AT!NV=3461,01
#
# Usage: SERIAL:AT!NV=ENSEN,<value>
#     value = 0 disabled (default)
#     value = 1 enable, for AT&T only
#
#SERIAL:AT!ENSEN=0

############## Disable FDN Check for data calls
# Applies to: AT&T only
#
# SWI Ref: G026 & G027
#
# Usage: SERIAL:AT!CUSTOM="DISFDNPDPCHK",<value>
#    value = 00 enable FDN check (default)
#    value = 01 disable FDN check on PDP activation
#    value = 02 disable FDN check for SMSC address
#    value = 03 both disabled
#
# Note: For FW older than 6280 H1.1.x.x, and 7200 all, this
#       command only has one option:
#    value = 00 enable FDN check (default)
#    value = 01 disable FDN check on PDP activation
#
#SERIAL:AT!CUSTOM="DISFDNPDPCHK",0

############## Receive Diversity ##########
# Applies to: Not applicable to 6280 FW.
#
# SWI Ref: G030
# 
# Usage: SERIAL:AT!RXDEN=<value>
#     value = 0 disabled
#     value = 1 enabled (default)
#     value = 2 Rx Diversity as primary path, used in internal
#               testing only. Do not use it for PRI.
#
#SERIAL:AT!RXDEN=1

############## Equalizer ##################
# Applies to: Not applicable to 6280 FW older than H1.0.0.7 or older than H1.1.0.1
# 
# SWI Ref: G031
#
# Usage: SERIAL:AT!EQEN=<value>
#     value = 0 disabled
#     value = 1 enabled (default)
#
#SERIAL:AT!EQEN=1

############## SMS Status Report ##########
# Applies to: Not applicable to 6280 FW older than H2.0.4.2
# 
# SWI Ref: G109
#
# Usage: SERIAL:AT!SMSSTSEN=<value>,<readonly>
#     value = 0 disabled (default)
#     value = 1 enabled 
#     readonly = 0 user is able to change the setting via CnS (default)
#     readonly = 1 user is unable to change the setting via Cns
#
#SERIAL:AT!SMSSTSEN=0,0

############## SMS Retry ##################
# Applies to: Not applicable to 6280 FW
#
# SWI Ref: G110 & G111
# 
# Description: Parameters to determine how long and how often to retry
#     if the SMS MO procedure failed due to network reject or failure.
# 
# Usage: SERIAL:AT!SMSRETRY=<period>,<interval>
#     period   = in seconds, how long the retry will last (default: 240)
#     interval = in seconds, how often the retry is sent (default: 5)
#
#SERIAL:AT!SMSRETRY=240,5

############## Dedicated CSD Port #########
# Applies to: 6290 FW newer than K2.0.6.9
#
# SWI Ref: G112
# 
# Description: This command is used to configure the secondary SIO port
#     for Circuit Switched Data
# Usage: SERIAL:AT!MAPCSD=<value>
#     value = 1, AT Command (Default)
#     value = 5, PDP1
#     value = 6, PDP2
#     value = 7, PDP3
#
# For all FW and 6290 FW older than K2.0.6.9, following should be used. 
# Usage: SERIAL:AT!CSDONSIO2=<value>
#     value = 0, CSD on main AT port (Default)
#     value = 1, CSD on MUX1 or VSP1 
#     value = 2, CSD on MUX2 or VSP2 (Only option for 6290 FW newer than K2.0)
#     value = 3, CSD on MUX3 or VSP3
#
#SERIAL:AT!MAPCSD=1

################ SIM behaviour in Low Power Mode ###############
# Applies to: TBD
#
# SWI Ref: G126
#
# Description: SIM remains powered on during +CFUN=0
#
# Usage: SERIAL:AT!CUSTOM="SIMLPM",<value>
#     value = 0, Default (device dependent)
#     value = 1, Do not power down SIM when +CFUN=0
#     value = 2, Power down SIM when +CFUN=0
#
#SERIAL:AT!CUSTOM="SIMLPM",0

############## Disable DM Port ############
# Applies to: TBD
#
# SWI Ref: G127
#
# Description: Disable QXDM port on modem
#
# Usage: SERIAL:AT!CUSTOM="USBDMDISABLE",<value>
#     value = 0, Enabled (Default)
#     value = 1, Disabled
#
#SERIAL:AT!CUSTOM="USBDMDISABLE",0

############## Black Box Logging ##########
# Applies to: TBD
#
# SWI Ref: TBD
# 
# Description: Black Box Logging options
#
# Usage: SERIAL:AT!CUSTOM="BBENABLE",<value>
#      value = 0, Disabled (Default)
#      value = 1, Enabled
#
#SERIAL:AT!CUSTOM="BBENABLE",1

############## Remote Diagnostic ##########
# Applies to: TBD
#
# SWI Ref: TBD
#
# Description: Configure Remote Diagnotic options
#
# Usage: SERIAL:AT!CUSTOM="RDENABLE",<value>
#      value = 0, Disabled (Default)
#      value = 1, Enabled
#
#SERIAL:AT!CUSTOM="RDENABLE",1

############## Repeated SACCH/FACCH #######
# Applies to: 8200 M2.0 FW or newer
#
# SWI Ref: G128
# 
# Description: R-SACCH allows SACCH blocks to be repeated on the uplink and downlink to improve 
#              signaling reliability.
#              R-FACCH allows downlink FACCH blocks to be repeated in order to improve robustness
#              of FACCH signaling during handovers. 
#
# Usage: SERIAL:AT!RACCHEN=<value>
#     value = 0 Disabled R-SACCH/R-FACCH
#     value = 1 Enabled R-SACCH/R-FACCH
#
#SERIAL:AT!RACCHEN=0

############## OSP WWAN Interface Support #######
# Applies to: TBD
# 
# SWI Ref: TBD
# 
# Description: Configure OSP WWAN Interface support
#
# Usage: SERIAL:AT!CUSTOM="OSPWWANENABLE",<value>
#      value = 0, Default
#      value = 1, Enabled
#      value = 2, Disabled
#
#SERIAL:AT!CUSTOM="OSPWWANENABLE",0

############## Win7 Mobile Options #############
# Applies to: TBD
# 
# SWI Ref: TBD
#
# Description: Configure Win7 MB Options
#
# Usage: SERIAL:AT!CUSTOM="WIN7MBOPTIONS",<value>
#     bit 0: Profile Hide;
#            0 - Default
#            1 - Force OSP to hide all profiles from host 
#     bit 1: Connect Auth Type Re-Map
#            0 - 'None' from host maps to CHAP/PAP if user name or password present
#            1 - 'None' from host maps to PAP if user name or password present
#     
#SERIAL:AT!CUSTOM="WIN7MBOPTIONS",00

############## UART Baudrate #############
# Applies to: All
# 
# SWI Ref: G134
# 
# Description: Set UART Baudrate
#
# Usage: SERIAL:AT+IPR=<value>
#     value = 300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200, 230400
# 
#SERIAL:AT+IPR=300

############## UART Mapping #############
# Applies to: 6290 K1.1 or newer, MDM6200/8220/9200/9600 all release, not applicable to 8200 FW
# 
# SWI Ref: G135
# 
# Description: Used to map a service running to the main UART. 
#
# Usage: SERIAL:AT!MAPUART=<value>
#     value = 0, UART Disabled
#             7, PDP3 Service (default)
# 
#SERIAL:AT!MAPUART=7

############### LTE Feature Group Indicators #############
# Applies to: Only applicable for LTE devices, 9200 1.0.3.1/9200 3.0.5.2 or newer
#
# SWI Ref: TBD
#
# Description: Update the field Feature Group Indicators (FGI) sent to the network
#              in LTE RRC UE_EUTRA-Capability message.
#
# Usage: SERIAL:AT!LTEFGI=<op>,<bitmask>
#     op      = 0, Default
#               1, Write
#     bitmask = 00000000 to FFFFFFFF
#             = 08080080 - DoCoMo FGI
#             = FFFFFFFF - Enable all supported features
#
#SERIAL:AT!LTEFGI=01,FFFFFFFF

############## PDP Context deactivation on power-down ######
# Applies to: MDM9200 ?SWI9200X_03.00.05.02 and above
#
# SWI Ref: TBD
#
# Description: Configure feature to deactivate PDP contexts when entering 
#              Low Power Mode.
#
# Usage: SERIAL:AT!NV=6478,<value>
#      values = 00, Default, detach on entering LPM
#               01, Deactivate PDP contexts before detaching on entering LPM
#
#SERIAL:AT!NV=6478,01

############### Single APN Switch #############
# Applies to: TBD
#
# SWI Ref: G136
#
# Description: Setup device behavior upon APN switch in LTE mode
#
# Usage: SERIAL:AT!CUSTOM="SINGLEAPNSWITCH",<mode>
#    mode = 0, Power cycle device upon APN switch in LTE mode
#           1, Detach and re-attach to network using new APN upon APN switch in LTE mode
#           2, Do nothing upon APN switch in LTE mode
#
#SERIAL:AT!CUSTOM="SINGLEAPNSWITCH",0

############## Default SAR Backoff State ###########
# Applies to: MDM9200, MDM9600, MDM6200
#
# SWI Ref: SAR001
#
# Description: Set the default SAR (Specific Absorption Rate) backoff state used
#              when the device powers up.
#
# Usage: SERIAL:AT!SARSTATEDFLT=<value>
#      values = 0, No backoff
#               1-8, Backoff state 
#
#SERIAL:AT!SARSTATEDFLT=0

############## SAR Maximum Tx Power ##########
# Applies to: MDM9200, MDM9600, MDM6200
#
# SWI Ref: SAR002, SAR003
# 
# Description: Set the maximum Tx power for a specific band
#
# Usage: SERIAL:AT!MAXPWR=<BAND>,<TECH>,<MAXPWR>
#      BAND = band number 
#      TECH = 0, WCDMA
#             2, LTE
#             3, GSM
#      MAXPWR = maximum power in dBm (integer value)
#
#SERIAL:AT!MAXPWR=1,0,30


############## SAR Backoff ##############
# Applies to: MDM9200, MDM9600, MDM6200
#
# SWI Ref: SAR002,SAR004,SAR005,SAR006
#
# Description: Set SAR backoff values
#
# Usage: SERIAL:AT!SARBACKOFF=<TECH>,<BAND>,<STATE>,<BACKOFF>
#
#            WCDMA                   CDMA                      LTE
# Tech     = 0                       1                         2
# Band     = 1,2,4,5,8,9,11          Low bands:  0,3,5,10,11   (1-5),7,8,11,13,17,18,20,38,40)
#                                    High bands: 1,4,6,14,15
# State    = 1-8                     1-8                       1-8
# Backoff  =  Band    Valid Range    Band    Valid Range       Band    Valid Range
#             Band 1: 0 - 93         Band 0: 0 - 83            Band 1: 0 - 93 
#             Band 2: 0 - 93         Band 1: 0 - 83            Band 2: 0 - 93
#             Band 4: 0 - 94         Band 3: 0 - 83            Band 3: 0 - 93
#             Band 5: 0 - 93         Band 4: 0 - 83            Band 4: 0 - 93
#             Band 8: 0 - 94         Band 5: 0 - 83            Band 5: 0 - 93
#             Band 9: 0 - 94         Band 6: 0 - 83            Band 7: 0 - 93
#             Band 11: 0 - 94        Band 10: 0 - 83           Band 8: 0 - 93 
#                                    Band 11: 0 - 83           Band 11: 0 - 93
#                                    Band 14: 0 - 83           Band 13: 0 - 93
#                                    Band 15: 0 - 83           Band 17: 0 - 93
#                                                              Band 18: 0 - 93
#                                                              Band 20: 0 - 93
#                                                              Band 38: 0 - 93
#                                                              Band 40: 0 - 93 
#                    
#Usage: SERIAL:AT!SARBACKOFF=<TECH>,<BAND>,<SLOT>,<STATE>,<MOD>,<BACKOFF>
#         
#          GSM
# Tech    = 3
# Band    = 0(Band 850)
#           1(Band 900)
#           2(Band 1800)
#           3(Band 1900)
# Slot    = 1-5
# State   = 1-8
# Mod     = 0 (GMSK)
#           1 (8PSK)
# Backoff = Slots    Valid Range
#             1           0
#             2          0-5
#             3          0-6.8
#             4          1-8
#
#SERIAL:AT!SARBACKOFF=3,0,1,1,1,0

############## Set L2 passwd #############
# Applies to: All
#
# Description: Default to A710.
#     Always define it per Riley's request. For MiniCards this
#     should be maintained as A710 or as defined by the OEM.
#
SERIAL:AT!SETCND="A710"

############## Set L3 passwd #############
# Applies to: All
#
# Description: Default to A710. 
#     Always Clear this Password.
#
#SERIAL:AT!SETLOCK=""

###############################################################################
####### OMA-DM (FOTA) Settings                        #######################
###############################################################################

############## DM Account Credentials ################
# Applies to: TBD
#
# SWI Ref: TBD
#
# Description: Setup DM account. 
#
# Usage: SERIAL:AT!IDSCREATEACC=<idx>,<SERVERADD>,<SERVERID>,<SERVERPASS>,<CLIENTUSERNAME>,<CLIENTPASS>
#     idx  = Index (1-2)
#     SERVERADD = URL of DM Server (121 Chars Max.)
#     SERVERID = DM Server ID (32 Chars Max.)
#     SERVERPASS = DM Server Password (32 Chars Max.)
#     CLIENTUSERNAME = DM Client User Name (32 Chars Max.)
#     CLIENTPASS = DM Client Password (32 Chars Max.)
#
#SERIAL:AT!IDSCREATEACC=1
#
# For AT&T only
# Description: Setup FOTA server account. (ATT only)
#              RCT 2.3.0.2 & up
# Usage: SERIAL:CAT!SETFOTA=<idx>,<URLS>,<SERVERID>
#     idx  = Index
#     URLS = Server URL
#     SERVERID = Server ID
#
#SERIAL:CAT!SETFOTA=1,"https://voemfotalab.pdg.bellsouth.net:443/opm/ht/omadm/dm","Cingularlab"

############## DM Account Authentication mode and XML format ################
# Applies to: TBD
#
# SWI Ref: TBD
#
# Description: Setup Authentication mode and XML format. 
#
# Usage: SERIAL:AT!IDSCONFIGACC=<idx>,<AUTH>,<XML>
#     idx  = Index (1-2)
#     AUTH = NONE - No Authentication
#            BASIC - Basic Authentication
#            Digest - MD5 Authentication
#            HMAC - HMAC Authentication
#     XML  = XML - XML format
#            WBXML - WBXML format
#
#SERIAL:AT!IDSCONFIGACC=1,NONE,XML

############## OMA-DM Session Setup ######################
# Applies to: TBD
#
# SWI Ref: WU001,WU002
#
# Description: To enable/disable Client initiated and server initiated DM sessions. 
#              DM sessions can be of type configuration for general device or FOTA updates.
#
# Usage: SERIAL:AT!IDSSUPPORT=<CT>,<NI>,<CIFOTA>,<NIFOTA>,<WUFOTA>,<WUSTAT>
#     CT = 0, Disable Client Initiated DM config session
#          1, Enable Client Initiated DM config session
#     NT = 0, Disable Network Initiated DM config session
#          1, Enable Network Initiated DM config session
#     CTFOTA = 0, Disable Client Initiated DM FOTA session
#              1, Enable Client Initiated DM FOTA session
#     NTFOTA = 0, Disable Network Initiated DM FOTA session
#              1, Enable Network Initiated DM FOTA session
#     WUFOTA = 0, Disable WebUpdater FOTA session
#              1, Enable WebUpdater FOTA session
#     WUSTAT = 0, Disable WebUpdater Statistic Collection
#              1, Enable WebUpdater Statistic Collection
#
#SERIAL:AT!IDSSUPPORT=1,1,1,1,1,1

############## OMA-DM Client Roaming Option ######################
# Applies to: TBD
#
# SWI Ref: TBD
#
# Description: If roaming is enabled, the client will attempt to connect to the server both on home 
#              and roaming networks. If disabled, the DM client will not attempt to connect to DM server when roaming.
#
# Usage: SERIAL:AT!IDSROAM=<value>
#     value = 0, DM session not allowed when roaming
#             1, DM session allowed when roaming
#
#SERIAL:AT!IDSROAM=1

############## OMA-DM Connection Profile ID ######################
# Applies to: TBD
#
# SWI Ref: TBD
#
# Description: Set the connection Profile ID that OMA-DM must use for its data connection. 
#              If this command is un-initialized, WebUpdater will use default PID
#
# Usage: SERIAL:AT!IDSPID=<LTE>,<3GPP>,<eHRPD>
#     LTE = 0, Use connected or default PID
#           1-16, PID
#     3GPP = 0, Use connected or default PID
#            1-16, PID
#     eHRPD = 0, Use connected or default PID
#             101-150, PID
#
#SERIAL:AT!IDSPID=0,0,0

############## OMA-DM Subscriber DM GUI response ################
# Applies to: TBD
#
# SWI Ref: TBD
#
# Description: Configures the Subscriber Device Management GUI response associated with OMADM. 
#
# Usage: SERIAL:AT!IDSAUTOSDM=<AUTOSDM>
#     AUTOSDM = 0, Permission from host application is required before proceeding with SDM session
#               1, Do not notify the host. Always ACCEPT SDM session
#               2, Do not notify the host. Always REJECT SDM session
#
#SERIAL:AT!IDSAUTOSDM=0

############## Setup FOTA ################
# Applies to: TBD
#
# SWI Ref: TBD
#
# Description: Setup autodownload, autoupdate, and autocheck flag with FOTA update. Device skips requesting user 
#              permissin before proceeding with download or update when enabled. When autocheck is enabled, the device
#              starts a device initiated FOTA session on every start up to check if the server has a firmware update available. 
#
# Usage: SERIAL:AT!IDSAUTOFOTA=<AUTODOWNLOAD>,<AUTOUPDATE>,<AUTOCHECK>
#     AUTODOWNLOAD  = 0 - Disable
#                     1 - Enable
#     AUTOUPDATE = 0 - Disable
#                  1 - Enable
#                  2 - Auto Update on Power up
#     AUTOCHECK  = 0 - Disable
#                  1 - Enable
#
#SERIAL:AT!IDSAUTOFOTA=1,1,1

############### WebUpdater Update Interval #########
# Applies to: TBD
#
# SWI Ref: WU008
#
# Description: Setup WebUpdater update interval. This command is independent of IDSAUTOFOTA command. If this is 
#              set, WebUpdater will do scheduled update even AUTOUPDATE is disabled with IDSAUTOFOTA.
#
# Usage: SERIAL:AT!WUCHECKINT=<value>
#      value = check interval in minutes (Eg. 10080 for weekly check)
#
#SERIAL:AT!WUCHECKINT=10080

############### WebUpdater Server ############
# Applies to: TBD
# 
# SWI Ref: WU005,WU006,WU007
#
# Description: Setup WebUpdater Server
#
# Usage: SERIAL:AT!WUURL=<UPDATEURL>,<DOWNLOADURL>,<SUMMARYURL>
#     UPDATEURL   = Update URL (Eg. https://updates.sierrawireless.com/swiwu/updates.aspx)
#     DOWNLOADURL = Download URL (Eg. https://updates.sierrawireless.com/swiwu/download.aspx)
#     SUMMARYURL  = Summary URL (Eg. https://updates.sierrawireless.com/swiwu/summary.aspx)
#
#SERIAL:AT!WUURL="https://updates.sierrawireless.com/swiwu/updates.aspx","https://updates.sierrawireless.com/swiwu/download.aspx","https://updates.sierrawireless.com/swiwu/summary.aspx"

############### WebUpdater Authentication ############
# Applies to: TBD
#
# SWI Ref: WU003,WU004
#
# Description: Setup WebUpdater authentication
#
# Usage: SERIAL:AT!WUAUTH=<USERNAME>,<PASSWORD>
#     USERNAME = User Name
#     PASSWORD = Password
#
#SERIAL:AT!WUAUTH="webupdt_eagle","ph1II3"

###############################################################################
####### Carrier Customizations - MiniCard only Settings #######################
###############################################################################

############## Sleep Mode ################
# Applies to: All. Currently only MiniCards use it.
#
# SWI Ref: M003
#
# Description: also known as Clocking/Low Power Mode.
#
# Usage: SERIAL:AT!SLEEP=<value>
#     value = 0 Slow clocking mode disabled (default)
#     value = 1 Slow clocking mode enabled
#
#SERIAL:AT!SLEEP=1

############## Start in LowPowerMode #####
# Applies to: MiniCards only. 
#             Not applicable to 6280 FW
# 
# SWI Ref: M004
#
# Description: When this feature is enabled, the modem stays in 
#      Low Power Mode (LPM, aka Flight Mode) after start up. The modem 
#      is powered on however the radio is disabled. It will not
#      register to the network. 
#
# Usage: SERIAL:AT!CUSTOM="STARTLPM",<value>
#     value = 0 disabled (default)
#     value = 1 enabled, modem will be in LPM after warm or cold restart
#
#SERIAL:AT!CUSTOM="STARTLPM",0

############## WLAN switch off ###########
# Applies to: Minicards only.
#
# SWI Ref: M005
#
# Description: Used to set the behavior of modem when laptop's
#     WLAN switch is turned off (W_DISABLE asserted).
#
# Usage: SERIAL:AT!PCOFFEN=<state>
#     state = 0 Enter Low Power Mode on W_DISABLE
#     state = 1 Power off modem on W_DISABLE 
#               (recommended, default for 6275, 6280)
#     state = 2 Ignore W_DISABLE event (default for 7200) 
#
#SERIAL:AT!PCOFFEN=1

############## Default volume for MC #####
# Applies to: MiniCards, voice is enabled.
#
# SWI Ref: M006
#
# Usage: SERIAL:AT+CLVL=<value>
#     value = 0-7, 0 lowest, 7 highest, 2 default.
#
#SERIAL:AT+CLVL=2

############## LED Customization #########
# Applies to: MiniCards only. Currently only HP and NetComm use it.
#
# SWI Ref: M008, M009, M010, M011, M012, M013, M014
#
# Note: id = 5 (DATA ACTIVE) only applies to MC8780 F1.0.0.19 and later. 
#      Invert option only applies to MC8790 or MC8785.
#
# Usage: SERIAL:AT!LEDCTRL=<id>,<period>,<ontime>,<invert>
#      id = 0 OFF, M009
#      id = 1 OUT OF SERVICE (Searching), M010
#      id = 2 IN SERVICE (Registered), M011
#      id = 3 CALL ACTIVE (Connected - Circuit Switched and 
#             Packet Switched), M012
#      id = 4 OFFLINE (Note: This is CDMA specific. UMTS/GPRS 
#             goes to sleep and turn off the LED), M013
#      id = 5 DATA ACTIVE (Packet Switched), M014
#      period = LED period in millisecond
#      ontime = LED ON duration in millisecond
#      invert = 0 on in first phase (default)
#      invert = 1 on in second phase, i.e. LED remains off during ontime 
#               and on during offtime
#
#SERIAL:AT!LEDCTRL=1,1000,1000

############## WCDMA Scan Threshold ######
# Applies to: All. Currently only MiniCards use it.
#             Not applicable to 6280 FW older than H1.1.8/9.13 or H2.0.3.6
#
# Description: During WCDMA acquisition, the UE performas a raw scan
#    every 10 channels to discover potential network candidates. 
#    Currently, a default of -103 dBm threshold is used for the raw
#    scan. Some hosts may have noise thresholds near or above the -103
#    dBm threshold. As a result, there are a number of 'false positives',
#    which increases the scan time for WCDMA. Raising this threshold
#    can shorten the scan time but will not allow the modem to acquire 
#    weak systems.
#
# Note: Please leave this command commented out if the customer
#    prefers to use Default value.
#
# Usage: SERIAL:AT!SCANTHRESH=<value>
#      value = -103 to -98 in dBm, -103 is default
#
#SERIAL:AT!SCANTHRESH=-103

############## RF Indicator #######
# Applies to: TBD
#
# SWI Ref: M015
# 
# Description: Determines whether to indicate the status of GPS ON/OFF and which band modem 
#              is operating under using DIO 3&4.
#
# Usage: SERIAL:AT!CUSTOM="RFINDENABLE",<value>
#     value = 0 Disable RF indicator
#     value = 1 Enable RF indicator
#
#SERIAL:AT!CUSTOM="RFINDENABLE",1

############### GNSS Antenna Configuration ############
# Applies to: TBD
#
# SWI Ref: M016
# 
# Description: Determines GNSS antenna configuration.
#
# Usage: SERIAL:AT!CUSTOM="GPSSEL",<value>
#     value = 0 Dedicated antenna for GNSS, 3.3V DC Bias (Default)
#     value = 1 GNSS antenna is shared with RxD antenna
#     value = 2 Dedicated antenna for GNSS, no DC Bias
#
#SERIAL:AT!CUSTOM="GPSSEL",0

################ Use of IMEI as Serial number in USB Descriptor ##################
# Applies to: TBD
#
# SWI Ref: M017
#
# Description: Control the use of the IMEI as the serial number in USB descriptor. This is 
#              a requirement for embedded devices, to meet Microsoft Spec.
#
# Usage: SERIAL:AT!CUSTOM="USBSERIALENABLE",<value>
#      value = 2, Disable the use of IMEI as serial number
#
#SERIAL:AT!CUSTOM="USBSERIALENABLE",2

###############################################################################
####### Carrier Customizations - TRU-install Settings #########################
###############################################################################

# Note: All TRU-install/SWoC parameters are mandatory. The image containing
#       Windows and/or Mac host software is downloaded in the DOWNLOAD section.

############## TRU-install/SWoC ###########
# Applies to: Not applicable to 6280 FW, 6290 FW, or 
#                               7200R3 FW older than F1.0.0.3
#
# Description: TRU-install is aka SWoC. This command cleans up any existing
#     SWoC image. All PRIs that do not use TRU-install needs to set this to
#     true; while all PRIs that uses TRU-install needs to set this to false.
#
# SWI Ref: T001
#
# Usage: SERIAL:AT!SWOCINVALIDATE to clean up SWoC image (use when SWoc disabled)
#        comment out this command for keeping the SWoC image (use when SWoC enabled)
#
#SERIAL:AT!SWOCINVALIDATE

############## Enable and Configure ######
# Applies to: Not applicable to 6280 FW, or 6290 FW
#
# Description: TRU-install is aka SWoC. This value is a bit mask:
#    bit 0: SWoC enable bit. A valid SWoC image must also be present in
#           flash in order to have an effect.
#    bit 1: Bypass SWoC on soft reboot.  When the modem is rebooted, do 
#           not start up as a mass storage device.  Go directly to modem 
#           mode. I.e. SWoC only active on cold-boot. This is used mostly
#           on minicards.
#
# SWI Ref: T001
#
# Usage: SERIAL:AT!CUSTOM="SWOCENABLE",<value>
#      value = 0, TRU-install disabled (default)
#      value = 3, TRU-install enabled, start in storage mode only in cold-boot
#
#SERIAL:AT!CUSTOM="SWOCENABLE",0

###############################################################################
####### Carrier Customizations - GPS Settings #################################
###############################################################################

############## GPS Overall Setting ########
# Applies to: All
#
# SWI Ref: A001
#
# Description: Enables GPS functionality in FW, and enables NMEA port when
#     applicable. When GPS is disabled, none of the GPS commands will take 
#     effect.
#
# Usage: For all 6280 FW, 7200R3 F1.0.x FW:
#     SERIAL:AT!CUSTOM="GPSENABLE",<value>
#       value = 0 GPS disabled, NMEA port disabled (default)
#       value = 1 GPS enabled, NMEA port enabled
#
#     For 7200R3 F1.2.0.0 - F1.2.3.5, 7200A J0.0.3.6 - J0.0.4.4 FW:
#     SERIAL:AT!GPSENABLE=<gps>,<classmark>
#       gps       = 0 GPS disabled, NMEA port disabled (default)
#       gps       = 1 GPS enabled, NMEA port enabled
#       classmark = 0 modem does not disclose its GPS capability to the 
#                     network (default)
#       classmard = 1 modem discloses its GPS capability to the network
#
#     For 7200R3 F1.2.3.6 and later, 7200A J0.0.4.5 and later FW, 6290 FW all:
#     SERIAL:AT!CUSTOM="GPSENABLE",<value>
#       value = 0 GPS disabled, NMEA port disabled (default)
#       value = 1 MO and MT GPS enabled, NMEA port enabled
#       value = 2 MO GPS enabled, NMEA port enabled
#       value = 3 MT GPS enabled, NMEA port disabled
#     where MO: Mobile originated (mobile initiated) position fixes
#           MT: Mobile terminated (network initiated) position fixes, the
#           NMEA port is enabled only when the network requests position fixes.
#     
#     For 9200 3.x and later:
#     SERIAL:AT!CUSTOM="GPSENABLE",<value>
#       value = 0 GPS disabled, NMEA port disabled (default)
#       value = 1 MO and MT GPS enabled, NMEA port enabled
#       value = 2 MO GPS enabled, NMEA port enabled
#       value = 3 MT GPS enabled, NMEA port disabled
#       value = 4 MO and MT GPS enabled, NMEA port enabled, GPS_DISABLE pin monitored
#       value = 5 MO GPS enabled, NMEA port enabled, GPS_DISABLE pin monitored
#       value = 6 MT GPS enabled, NMEA port disabled, GPS_DISABLE pin monitored
#     where 
#           MO: Mobile originated (mobile initiated) position fixes
#           MT: Mobile terminated (network initiated) position fixes, the
#           NMEA port is enabled only when the network requests position fixes
#     Note: GLONASS can be disabled by setting bit7 in <value> (i.e. add 128 to the desired value)
#
#SERIAL:AT!CUSTOM="GPSENABLE",1

############## MT LR Notification #########
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2.3.13
#
# SWI Ref: A030
#
# Description: This setting determines the notification behavior to the
#      end user when a Mobile Terminated Location Request comes in. "Network
#      determined" is done per 3GPP spec 23.271. If network requests Notify
#      Only, then a notification is displayed to the user. If the network
#      requests verification, then a verify message (accept or reject) is 
#      displayed to the user.
#
# Usage: SERIAL:AT!GPSMTLRSETTINGS=<value>
#       value = 0 Network Determined (default) 
#       value = 1 Accept All
#       value = 2 Reject All
#       value = 3 Verify All
#
#SERIAL:AT!GPSMTLRSETTINGS=0

############## GPS Mode ###################
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2
#
# SWI Ref: A002, A003, A004, A005, A006, A007, A008
#
# Description: This command can be used to turn off A-GPS (by allowing only
#     standalone mode).
#
# Usage: SERIAL:AT!GPSPOSMODE=<value>, where value is a bitmask
#     bit 0: Standalone
#     bit 1: UP MS-Based
#     bit 2: UP MS-Assisted
#     bit 3: CP MS-Based (2G)
#     bit 4: CP MS-Assisted (2G)
#     bit 5: CP UE-Based (3G)
#     bit 6: CP UE-Assisted (3G)
#
#     value = 0 All modes disabled, no GPS support
#     value = 1 Standalone mode, no A-GPS
#     value = 7F All modes enabled(default)
#
#SERIAL:AT!GPSPOSMODE=7F
#SERIAL:AT!GPSPOSMODE=1

############## HSLP IP/URL  ##############
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2.3.9
#
# SWI Ref: A009
#
# Description: When in User Plane mode, this defines the IP address or SUPL URL string
#     to be used when TCP/IP is the transport mechanism for location Processing.
#
# Usage: SERIAL:AT!GPSSUPLURL="<hostname>"
#            hostname = hostname/IP address string in dotted format
#
#SERIAL:AT!GPSSUPLURL="123.123.123.123"
#SERIAL:AT!GPSSUPLURL="supl.server.com"

############## HSLP Server Port  ##############
# Applies to: Not applicable to 6280,8200 FW, 7200R3 FW older than F1.0.1.4
#
# SWI Ref: A010
#
# Description: When in User Plane mode, this defines the port number 
#              to be used when TCP/IP is the transport mechanism for 
#              Location Processing.
# 
# Usage: SERIAL:AT!GPSPORTID=<port>
#             port = port ID
#
#SERIAL:AT!GPSPORTID=1234

############## SUPL Transport Security ####
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2
#
# SWI Ref: A011
#
# Description: When in User Plane mode, this defines GPS transport security.
#
# Usage: SERIAL:AT!GPSTRANSSEC=<value>
#     value = 0 disabled (default)
#     value = 1 enabled
#
#SERIAL:AT!GPSTRANSSEC=1
#SERIAL:AT!GPSTRANSSEC=1

############## SUPL Profile ID ####
# Applies to: Not applicable to 6280 FW, 7201 FW, 6290 FW older than K2.0.7.19 
#
# SWI Ref: A037
#
# Description: This command will set the connection Profile ID that GPS must use
#              for its supplementary channel
#
# Usage: SERIAL:AT!GPSSUPLPID=<pid>
#     pid = 0  Use connected or default Profile ID
#     pid = 1 -16 Profile ID
#
#SERIAL:AT!GPSSUPLPID=0

############## Protocol Selection #########
# Applies to: Not applicable to 6280, 7200A FW, 7200R3 FW older than F1.2
#
# SWI Ref: TBD
#
# Note: For A-GPS, currently SUPL is the only choice for protocol selection.
#     However, since older 7200R3 firmware might use preSUPL as default,
#     This need to be here to make sure it's set to SUPL.
#
# Usage: SERIAL:AT!GPSPROTOSEL=<value>
#     value = 0 none
#     value = 1 PreSUPL
#     value = 2 X1
#     value = 3 SUPL (default)
#
#SERIAL:AT!GPSPROTOSEL=3

############## gpsOneXTRA Data Settings ###
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2
#
# SWI Ref: A016
#
# Usage: SERIAL:AT!GPSXTRADATAENABLE=<value>
#      value = 0 XTRA data download disabled
#      value = 1 XTRA data download enabled (default)
#      value = 2 XTRA data download enabled and embedded QCT XTRA Client (QMI mode only)
#
#SERIAL:AT!GPSXTRADATAENABLE=1

############## gpsOneXTRA Data Servers ####
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2
#
# SWI Ref: A021, A022, A023
#
# Usage: SERIAL:AT!GPSXTRADATAURL=<id>,<url>
#     id  = server id, 3 can be defined. value 1-3
#     url = server URL, default values:
#           primary server  : "http://xtra1.gpsOneXTRA.net/xtra.bin"
#           secondary server: "http://xtra1.gpsOneXTRA.net/xtra.bin"
#           tertiary server : "http://xtra1.gpsOneXTRA.net/xtra.bin"
#
#SERIAL:AT!GPSXTRADATAURL=1,"http://xtra1.gpsOneXTRA.net/xtra.bin"
#SERIAL:AT!GPSXTRADATAURL=2,"http://xtra2.gpsOneXTRA.net/xtra.bin"
#SERIAL:AT!GPSXTRADATAURL=3,"http://xtra3.gpsOneXTRA.net/xtra.bin"

############## gpsOneXTRA Time ############
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2
#
# SWI Ref: A024, A025, A026
#
# Usage: SERIAL:AT!GPSXTRATIMEENABLE=<value>
#      value = 0 XTRA Time Info disabled
#      value = 1 XTRA Time Info enabled (default)
#      value = 2 XTRA Time Info enabled and embedded QCT XTRA Client (QMI mode only)
#
#SERIAL:AT!GPSXTRATIMEENABLE=1

############## gpsOneXTRA Time Servers ####
# Applies to: Not applicable to 6280 FW, 7200R3 FW older than F1.2
#
# SWI Ref: A027, A028, A029
#
# Usage: SERIAL:AT!GPSXTRATIMEURL=<id>,<url>
#     id  = SNTP server id, 3 can be defined. value 1-3
#     url = SNTP server IP or domain, default values:
#           primary server  : "xtra1.gpsOneXTRA.net"
#           secondary server: "xtra2.gpsOneXTRA.net"
#           tertiary server : "xtra3.gpsOneXTRA.net"
#
#SERIAL:AT!GPSXTRATIMEURL=1,"xtra1.gpsOneXTRA.net"
#SERIAL:AT!GPSXTRATIMEURL=2,"xtra2.gpsOneXTRA.net"
#SERIAL:AT!GPSXTRATIMEURL=3,"xtra3.gpsOneXTRA.net"

############## Mobile Originated Location Request ####
# Applies to: Applicable only to 6290 FW older than K1.1.1.10/K2.0.3.0
#
# SWI Ref: TBD
# 
# Usage: SERIAL:AT!GPSMOLRSETTING=<RAT>,<BITMASK>
#      RAT = Radio Access Technology settings apply to
#            0 - 2G,  1 - 3G
#      BITMASK = Bit-mapped settings for MO location request
#            bit 0: Low accuracy
#            bit 1: High accuracy
#            bit 2: Assistance data allowed
# 
#SERIAL:AT!GPSMOLRSETTING=0,7
#SERIAL:AT!GPSMOLRSETTING=1,7

############## GPS AutoStart ####
# Applies to: Applicable only to 6290 FW older than K1.0.2.1 or L1.0.2.1, 7201 FW older than F1.2.3.16
#             Not Applicable to MDM8200
#
# SWI Ref: A031-A035
#
# Description: This command to set GPS auto-start feature settings.
# 
# Usage: SERIAL:AT!GPSAUTOSTART=<value>,<Fixtype>,<Maxtime>,<Maxdist>,<fixrate>
#      value = 0 - Disabled, 1 - Enabled
#      Fixtype = 1 - Standalone, 2 - MS-Based, 3 - MS-Assisted
#      Maxtime = 1 - 255 Maximum time allowed for the receiver to get a fix. (Second)
#      Maxdist = 1 - 4294967280 Maximum distance uncertainty of a fix. (meters)
#      Fixrate = 1 - 65535 Time between fixes. (Second)
#
#SERIAL:AT!GPSAUTOSTART=1,1,255,100,1

############## GPS in LowPowerMode ####
# Applies to: TBD
#
# SWI Ref: A036
#
# Description: This command to enable GPS in Low Power Mode.
# 
# Usage: SERIAL:AT!CUSTOM="GPSLPM",<value>
#      value =  0 - Enable GPS in low power mode. (Default)
#               1 - Disable GPS in low power mode. Any active GPS session will be terminated 
#                   once low power mode is entered.     
#
#SERIAL:AT!CUSTOM="GPSLPM",0
#SERIAL:AT!CUSTOM="GPSLPM",1

###############################################################################
####### Carrier Customizations - Profile Settings #############################
###############################################################################

# Applies to: All
#
# Description: Please follow the steps. Up to 16
#     profiles can be defined here.
#
# Step 1, Define PDP Context
# Usage: SERIAL:AT+CGDCONT=<pid>,<pdp_type>,<apn>,<ip_addr>
#     pid      = profile id
#     pdp_type = Type of profile 
#                "IP", "IPV6", "IPV4V6" 
#     apn      = Access Point Name in strings
#     ip_addr  = optional, IP address, 0.0.0.0 for dynamic addr
#
#SERIAL:AT+CGDCONT=1,"IP","internet.com"
#SERIAL:AT+CGDCONT=1,"IP","lteinternet.apn"

# Step 2, Define authentication
# Usage: SERIAL:AT$QCPDPP=<pid>,<auth_type>,<password>,<username>
#     pid       = profile id
#     auth_type = 0 none (does not accept username/password)
#     auth_type = 1 PAP (accept username/password)
#     auth_type = 2 CHAP (only accept password)
#     username, password = username, password
#
#SERIAL:AT$QCPDPP=1,1,"Password","UserName"
#SERIAL:AT$QCPDPP=1,0

# Step 3: Define profile
# Usage: SERIAL:AT!SCPROF=<pid>,<label>,<autoconn>,<promptpwd>,
#        <autolaunch>,<pdplinger>
#     pid = profile id
#     label = profile label (name)
#     autoconn = 0 manual connect
#     autoconn = 1 auto connect
#     autoconn = 2 auto connect (Home Network Only)
#     promptpwd = 0 don't prompt for password
#     promptpwd = 1 prompt for password
#     autolaunch = 0 don't auto launch app
#     autolaunch = 1 auto launch app
#     pdplinger = PDP linger timer
#     pdplinger = 0 disabled
#     pdplinger = 1-32767 timer value
#
#SERIAL:AT!SCPROF=1,"Profile Name",0,0,0,0
#SERIAL:AT!SCPROF=1,"Rogers LTE",0,0,0,0

#
# Step 4: Software option settings
# 
# Usage: SERIAL:AT!SCPROFSWOPT=<PID>,<BITMASK>
#      PID = Profile ID
#      BITMASK = Bit-mapped software option settings
#            bit 1: 0 NDIS Profile
#                   1 DUN Profile
#            bit 2: 0 Enable TRU-Flow
#                   1 Disable TRU-Flow
#            bit 3: 0 Disable WINS
#                   1 Enable WINS
#            bit 4: 0 Enable DNS Negotiation
#                   1 Disable DNS Negotiation
#            bit 5: 0 Otherwise
#                   1 User Defined default
#            bit 6: 0 Otherwise
#                   1 Prompt for username
#            bit 7: 0 Visible Profile
#                   1 Hidden Profile 
#            bit 8:   Reserved for future use
# 
#SERIAL:AT!SCPROFSWOPT=1,00
#SERIAL:AT!SCPROFSWOPT=2,FF
#SERIAL:AT!SCPROFSWOPT=1,00

# Step 5 (optional): set pri and sec DNS addr
# Usage: SERIAL:AT!SCDNS=<pid>,<pri_dns>,<sec_dns>
#     pri = profile id
#     pri_dns = default primary DNS addr, 0.0.0.0 means dynamic
#     sec_dns = default secondary DNS addr, 0.0.0.0 means dynamic
#
#SERIAL:AT!SCDNS=1,"0.0.0.0","0.0.0.0"

# Step 6 (optional): Quality of Service Profile, requested
# Usage: SERIAL:AT+CGQREQ=<pid>,<precedence>, <delay>,<reliability>,
#                         <peak>,<mean>
#     pid = profile id
#     Please see AT command ref for the rest of the parameters.
#
#SERIAL:AT+CGQREQ=1

# Step 7 (optional): Quality of Service Profile, min acceptable
# Usage: SERIAL:AT+CGQMIN=<pid>,<precedence>, <delay>,<reliability>,
#                         <peak>,<mean>
#     pid = profile id
#     Please see AT command ref for the rest of the parameters.
#
#SERIAL:AT+CGQMIN=1

# Step 8 (optional): 3G Quality of Service Profile, requested
# Usage: SERIAL:AT+CGEQREQ=<pid>,<traffic_class>
#     pid = profile id
#     traffic_class = 0 conversational
#     traffic_class = 1 streaming
#     traffic_class = 2 interactive
#     traffic_class = 3 background
#     traffic_class = 4 subscribed value
#
#SERIAL:AT+CGEQREQ=1,2

# Step 9 (optional): 3G Quality of Service Profile, min acceptable
# Usage: SERIAL:AT+CGEQMIN=<pid>
#     pid = profile id
#
#SERIAL:AT+CGEQMIN=1

# Step 10: Define read-write permission
# Usage: SERIAL:AT!SCROPROF=<readonly>,<pid>
#     readonly = 0 readonly disabled, readable & writable (default)
#     readonly = 1 read-only
#     pid = profile id
#
#SERIAL:AT!SCROPROF=0,1
#SERIAL:AT!SCROPROF=0,1

############## Default Profile ###########
# Applies to: All
#
# SWI Ref: P001
#
# Usage: SERIAL:AT!SCDFTPROF=<pid>
#     pid = profile id
#
#SERIAL:AT!SCDFTPROF=1
#SERIAL:AT!SCDFTPROF=1

###############################################################################
####### Carrier Customizations - MEP Locking Settings #########################
###############################################################################

############## Remove MEP Data ###########
# Applies to: All
#
# Note: You should always clear MEP data even if there is no MEP locking
#     associated with the PRI. This ensures all MEP data is reset in case 
#     the modem had a MEP lock previously.
#
#SERIAL:AT!NVMEPRST

############## Unlocking Method ##########
# Applies to: All
#
# SWI Ref: L001
# 
# Description: If enabled, the MEP locking is permanent and cannot
#     be removed via Watcher or +CLCK. If disabled, MEP locking can
#     be removed via Watcher or +CLCK with correct unlock code.
#
# Usage: SERIAL:AT!CUSTOM="MEPLOCK",<value>
#     value = 0 disabled (default), can be unlocked with code
#     value = 1 enabled, permanently locked
#
#SERIAL:AT!CUSTOM="MEPLOCK",0

############## MEP Code Prompt ###########
# Applies to: All
#
# SWI Ref: L004
#
# Description: Determines Watcher will prompt user to enter MEP unlock 
#     code when an incorrect SIM is inserted in device. This command should
#     always be set to enabled unless requested by customers otherwise
#
# Usage: SERIAL:AT!CUSTOM="MEPCODE",<value>
#     value = 0 disabled (default)
#     value = 1 enabled
#
#SERIAL:AT!CUSTOM="MEPCODE",1

############## PLMN List for MEP locking #
# Applies to: All
#
# SWI Ref: L005 & L006
#
# Description: This is only required if MEP locking is enabled.
#     Test SIM's MCC-MNC (001,001) is always included by default,
#     hence does not need to be added here.
#     Up to 7 pairs per line and up to 64 MCC/MNC pairs can be
#     defined per SKU.
#
# Usage: SERIAL:AT!NVPLMN=<mcc>,<mnc>
#     mcc = MCC
#     mnc = MNC (3-digit for NA, 2-digit for rest of the world)
#
#SERIAL:AT!NVPLMN=123,01

############## Service Provider Code #######
# Applies to:
# 
# SWI Ref: L008
# 
# Description: This is only required if SP locking is enabled. 
#              (There must be at least one item in PLMN list for this to work)  
# 
# Usage: SERIAL:AT!NVSPCODE=<SP Code>
#    SP Code = 1 or 2 digits numeric Service Provider code
#
#SERIAL:AT!NVSPCODE=54

############### Network Subset Code #########
# Applies to:
#
# SWI Ref: L010
#
# Description: This is only required if NS locking is enabled. 
#              (There must be at least one item in PLMN list for this to work)
#
# Usage: SERIAL:AT!NVNSCODE=<NS Code>
#    NS Code = 2 digits numeric Network Subset code
#
#SERIAL:AT!NVNSCODE=00

############## Lock to PLMN List #########
# Applies to: All
#
# SWI Ref: L002 & L003 & L007 & L009
#
# Description: This is only required if MEP locking is enabled. It will
#     create a unlocking code based on the number of digits defined, and
#     send it to modem via AT+CLCK command.
#
# Usage: SERIAL:CAT!ME-LOCK=<type>,<digit>
#     type = 0 Network
#     type = 1 Network Subset
#     type = 2 Service provider
#     digit = number of digits for unlocking code
#
#SERIAL:CAT!ME-LOCK=0,8

###############################################################################
####### Hotspot Customizations                    #############################
###############################################################################

############## Device Name ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H001
#
# Description: Set Hotspot Device Name.
# 
# Usage: HOTSPOT:AT!HSDEVNAME="<value>"
#      value =  Device name in ASCII      
#
#HOTSPOT:AT!HSDEVNAME="Ultimate"

############# Domain Name #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H003
#
# Description: Domain name
#
# Usage: HOTSPOT:AT!HSRTRDOMAIN="<value>"
#      value = Host name in ASCII
#
#HOTSPOT:AT!HSRTRDOMAIN="Network"

############## Admin Password ######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H004
#
# Description: Admin Password
#
# Usage: HOTSPOT:AT!HSADMINPASS="<value>"
#      value = Password
#
#HOTSPOT:AT!HSADMINPASS="Password"

############## Activation ###########
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H005
#
# Description: When activation is required, all the traffic will be re-directed to the
#              device Web UI except for the domains listed in the exception list
#
# Usage: HOTSPOT:AT!HSCUSTACTRED=<value>
#      value = 0 - Activation not required
#              1 - Activation required
#
#HOTSPOT:AT!HSCUSTACTRED=0

############## DNS Poisoning ########
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H006
#
# Description: Force DNS Poisoning so all the traffic will be 
#              redirected to device Web UI
#
# Usage: HOTSPOT:AT!HSRTRDNSPFORCE=<value>
#      value = 0 - Do not force DNS poisoning
#              1 - Force DNS poisoning
#
#HOTSPOT:AT!HSRTRDNSPFORCE=0

############### DNS Exception list ######
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H007
#
# Description: Configure DNS exception list, only takes effect when DNS poisoning is enabled
#
# Usage: HOTSPOT:AT!HSRTRDNSPEXCLIST="<value>"
#      value = DNS exception
#
#HOTSPOT:AT!HSRTRDNSPEXCLIST="register.bigpond.com"

############ Standby on Idle ##########
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H008
#
# Description: Timer for automaticly turn Hotspot to standby on idle
#
# Usage: AC Timer:      HOTSPOT:AT!HSPWSTDBYACIDLETM=<value>
#        Battery Timer: HOTSPOT:AT!HSPWSTDBYBTIDLETM=<value>
#        USB Timer:     HOTSPOT:AT!HSPWSTDBYUSBIDLETM=<value>
#
#      value =  Time in MS, 0:Disable    
#
#HOTSPOT:AT!HSPWSTDBYACIDLETM=0
#HOTSPOT:AT!HSPWSTDBYBTIDLETM=0
#HOTSPOT:AT!HSPWSTDBYUSBIDLETM=0

############## Disable Terms and Conditions Agreement ####
# Applies to: TBD
#
# SWI Ref: H009
#
# Description: Terms and Conditions Aggrement
# 
# Usage: HOTSPOT:AT!HSCUSTTCAAED=<value>
#      value =  0 - Not Accepted
#               1 - Accepted      
#
#HOTSPOT:AT!HSCUSTTCAAED=1

############## Auto Connect to Home Network ######
# Applies to: TBD
# 
# SWI Ref: H010
#
# Description: Auto connect to Home network on startup
#
# Usage: HOTSPOT:AT!HSAUTOCONN=<value>
#     value = 0 - Disable
#             1 - Always
#             2 - Home Network Only      
#
#HOTSPOT:AT!HSAUTOCONN=2

############## Power LED Setting #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H011
#
# Description: Enable/Disable LED setting
#
# Usage: HOTSPOT:AT!HSLEDENA=<value>
#      value = 0 - Disable
#              1 - Enable
#
#HOTSPOT:AT!HSLEDENA=1

############### LCD Backlight Setting #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H012
#
# Description: LCD backlight setting
#
# Usage: HOTSPOT:AT!HSLCDBACKLIGHT=<value>
#      value = 0 - Disable
#              1 - Enable
#
#HOTSPOT:AT!HSLCDBACKLIGHT=1

############## LCD Inactivity Timer ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H013
#
# Description: LCD inactivity timer
# 
# Usage: HOTSPOT:AT!HSLCDINACT=<time>,<type>
#      time =  0 - Always On
#              time - in Second
#      type =  0 - On Battery (Default)
#              1 - On AC Power
#              2 - On USB Power      
#
#HOTSPOT:AT!HSLCDINACT=0,0

############### Backlight Setting - Battery #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H014
#
# Description: Backlight setting when unit on battery power
#
# Usage: HOTSPOT:AT!HSLCDBRIGHTBATT=<value>
#      value = 0 - Off
#              1 - Dim
#              2 - Bright
#
#HOTSPOT:AT!HSLCDBRIGHTBATT=1

############### Backlight Setting - USB #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H015
#
# Description: Backlight setting when unit on USB power
#
# Usage: HOTSPOT:AT!HSLCDBRIGHTUSB=<value>
#      value = 0 - Off
#              1 - Dim
#              2 - Bright
#
#HOTSPOT:AT!HSLCDBRIGHTUSB=1

############### Backlight Setting - AC #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H016
#
# Description: Backlight setting when unit on AC power
#
# Usage: HOTSPOT:AT!HSLCDBRIGHTAC=<value>
#      value = 0 - Off
#              1 - Dim
#              2 - Bright
#
#HOTSPOT:AT!HSLCDBRIGHTAC=1

############### Audio Mute State #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H056
#
# Description: Main switch for audio alert. If this is set to MUTE all auido 
#              alert is disabled and setting DXCFG=13,0 has no effect.
#
# Usage: HOTSPOT:AT!DXCFG=13,1,<value>
#      value = 0 - UNMUTE
#              1 - MUTE
#
#HOTSPOT:AT!DXCFG=13,1,0

############## Audio Alert ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H017,H018,H019,H020,H021,H022,H023,H024,H025,H026,H027
#
# Description: Enable audio alert
# 
# Usage: HOTSPOT:AT!HSAUDIOCFG=<value>
#      value = a combination of each
#            System Alert    - 0x00000001
#            Standby Entry   - 0x00000002
#            Standby Leave   - 0x00000004
#            Battery Low     - 0x00000008
#            Shutdown        - 0x00000010
#            WIFI Connect    - 0x00000020
#            WIFI Disconnect - 0x00000040
#            WWAN Connect    - 0x00000080
#            WWAN Disconect  - 0x00000100
#            Last User Left  - 0x00000200
#            SMS Received    - 0x00000400
#    
#      0x7FF - All enabled
#
#HOTSPOT:AT!HSAUDIOCFG=0x7FF

############## Enable Wi-Fi ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H028
#
# Description: Set Hotspot Wi-fi.
# 
# Usage: HOTSPOT:AT!HSWLANENABLE=<value>
#      value =  0 - Disable WIFI
#               1 - Enable WIFI      
#
#HOTSPOT:AT!HSWLANENABLE=1

############## SSID Broadcast ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H029
#
# Description: Broadcast SSID
# 
# Usage: HOTSPOT:AT!HSWLANHIDDENSSID=<value>
#      value =  0 - Enable broadcast
#               1 - Disable broadcast      
#
#HOTSPOT:AT!HSWLANHIDDENSSID=1

############## WiFi Range ##########
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H030
#
# Description: RF Range
#
# Usage: HOTSPOT:AT!HSWLANTXPOWER=<value>
#      value = 0   - Short Range
#              10  - Medium Range
#              128 - Long Range
#
#HOTSPOT:AT!HSWLANTXPOWER=0

############## Wi-Fi Channel ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H031
#
# Description: Set Wi-Fi Channel.
# 
# Usage: HOTSPOT:AT!HSWLANCHAN=<value>
#      value =  0     <Auto>
#               1-11  <US>    
#               12-14 <Other>  
#
#HOTSPOT:AT!HSWLANCHAN=0

############### Wi-Fi Physical Mode ########
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H032
#
# Description: Wi-Fi Mode.
#
# Usage: HOTSPOT:AT!HSWLANPHYMODE=<value>
#      value = 0 - 802_11B
#              1 - 802_11G
#              2 - 802_11N
#              3 - 802_11BG
#              4 - 802_11BGN
#              5 - 802_11Auto
#  
#HOTSPOT:AT!HSWLANPHYMODE=4

############## RTS Threshold ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H033
#
# Description: Set RTS Threshold.
# 
# Usage: HOTSPOT:AT!HSWLANRTSTHR=<value>
#
#HOTSPOT:AT!HSWLANRTSTHR=2347

############## Frag Threshold ####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H034
#
# Description: Set Frag Threshold.
# 
# Usage: HOTSPOT:AT!HSWLANFRAGTHR=<value>
#
#HOTSPOT:AT!HSWLANFRAGTHR=2346

############### Wi-Fi Encryption Type ########
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H035
#
# Description: Wi-Fi encryption type.
#
# Usage: HOTSPOT:AT!HSWLANENCRIP=<value>
#      value = 0 - None
#              1 - WEP64_OPEN
#              2 - WEP64_SHARED
#              3 - WEP128_OPEN
#              4 - WEP128_SHARED
#              5 - WPA_TKIP
#              6 - WPA_CCMP
#              7 - WPA2_TKIP
#              8 - WPA2_CCMP
#              9 - WPA_WPA2_MIXED
#  
#HOTSPOT:AT!HSWLANENCRIP=8

############## Wi-Fi Encryption Key Reminder #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H036
#
# Description: Display passphrase on screen as a reminder
# 
# Usage: HOTSPOT:AT!HSWLANPASSRMD=<value>
#      value =  0 - Disable 
#               1 - Enable    
#
#HOTSPOT:AT!HSWLANPASSRMD=1

############# Port Forwarding #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H037
#
# Description: Port forwarding setting
#
# Usage: HOTSPOT:AT!HSNATPORTFWDENA=<value>
#      value =  0 - Disable 
#               1 - Enable    
#
#HOTSPOT:AT!HSNATPORTFWDENA=0

############## VPN Pass through #####
# Applies to: 9200H1.0.2.0 or above
#
# SWI Ref: H038
#
# Description: Set VPN Pass through
# 
# Usage: HOTSPOT:AT!HSNATVPNPASS=<value>
#      value =  0 - Disable VPN Pass through
#               1 - Enable VPN Pass through   
#
#HOTSPOT:AT!HSNATVPNPASS=1

############# Router IP Address #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H039
#
# Description: Set Router IP address
#
# Usage: HOTSPOT:AT!HSWLANIP=<value>
#      value = IP address in Hex (Eg.0xC0A80101 for 192.168.1.1)
#
#HOTSPOT:AT!HSWLANIP=0xC0A80101

############# Subnet Mask #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H040
#
# Description: Set Router subnet mask
#
# Usage: HOTSPOT:AT!HSRTRNETMASK=<value>
#      value = IP address in Hex (Eg.0xFFFFFF00 for 255.255.255.0)
#
#HOTSPOT:AT!HSRTRNETMASK=0xFFFFFF00

############# Host Name #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H041
#
# Description: Host name
#
# Usage: HOTSPOT:AT!HSRTRHOSTNAME="<value>"
#      value = Host name in ASCII
#
#HOTSPOT:AT!HSRTRHOSTNAME="AC753S"

############# USB IP Address #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H042
#
# Description: Set USB IP Address
#
# Usage: HOTSPOT:AT!HSRTRUSBIP=<value>
#      value = IP address in Hex (Eg.0xC0A80202 for 192.168.2.2)
#
#HOTSPOT:AT!HSRTRUSBIP=0xC0A80202

############# DHCP Server #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H043
#
# Description: Set DHCP Server support
#
# Usage: HOTSPOT:AT!HSRTRDHCPENA=<value>
#      value =  0 - Disable 
#               1 - Enable    
#
#HOTSPOT:AT!HSRTRDHCPENA=1

############# DHCP Start address #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H044
#
# Description: Set DHCP Start address
#
# Usage: HOTSPOT:AT!HSRTRIPLOW=<value>
#      value = IP address in Hex (Eg.0xC0A80102 for 192.168.1.2)
#
#HOTSPOT:AT!HSRTRIPLOW=0xC0A80102

############# DHCP End address #######
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H045
#
# Description: Set DHCP End address
#
# Usage: HOTSPOT:AT!HSRTRIPHI=<value>
#      value = IP address in Hex (Eg.0xC0A80163 for 192.168.1.99)
#
#HOTSPOT:AT!HSRTRIPHI=0xC0A80163

############# DHCP Release Time ###########
# Applies to: TBD
#
# SWI Ref: H049
#
# Description: Set DHCP release time
#
# Usage: HOTSPOT:AT!DXCFG=6,15,<value>
#    <value> = Lease time in seconds
#
#HOTSPOT:AT!DXCFG=6,15,21600

############# DNS Mode ##########
# Applies to: 9200H1.0.2.0 or above
# 
# SWI Ref: H046,H047,H048
#
# Description: DNS Mode
#              Setting DNS1 the same as router IP and DNS2 as 0
#              enables DNS mode to be auto
#
# Usage: DNS1 - HOTSPOT:AT!HSRTRPRIDNS=<value>
#        DNS2 - HOTSPOT:AT!HSRTRSECDNS=<value>
#      value = IP address in Hex (Eg.0xC0A80101 for 192.168.1.1)
#
#HOTSPOT:AT!HSRTRPRIDNS=0xC0A80101
#HOTSPOT:AT!HSRTRSECDNS=0x00000000

############ Auto ON #############
# Applies to: TBD
#
# SWI Ref: N/A
#
# Description: Automaticly turn on 
# 
# Usage: HOTSPOT:AT!HSPWAUTOONENA=<value>
#      value =  0 - Disable auto on
#               1 - Enable auto on  
#
#HOTSPOT:AT!HSPWAUTOONENA=1

############## Auto off on USB Removal #####
# Applies to: TBD
#
# SWI Ref: H050
#
# Description: Automaticly turn off Hotspot on USB Removal
# 
# Usage: HOTSPOT:AT!HSPWAUTOOFFUSBDIS=<value>
#      value =  0 - Disable auto turn off
#               1 - Enable auto turn off   
#
#HOTSPOT:AT!HSPWAUTOOFFUSBDIS=0

############## Auto off on USB Removal Timer #####
# Applies to: TBD
#
# SWI Ref: N/A
#
# Description: Timer for automaticly turn off Hotspot on USB Removal, only
#              when option is enabled
#
# Usage: HOTSPOT:AT!HSPWAUTOOFFUSBDISTM=<value>
#      value =  Time in MS    
#
#HOTSPOT:AT!HSPWAUTOOFFUSBDISTM=1000

############ Auto off on Idle ##############
# Applies to: TBD
#
# SWI Ref: N/A
#
# Description: Timer for automaticly turn off Hotspot on idle
#
# Usage: AC Timer  - HOTSPOT:AT!HSPWAUTOOFFACIDLETM=<value>
#        USB Timer - HOTSPOT:AT!HSPWAUTOOFFBTIDLETM=<value>
#      value =  Time in MS, 0:Disable    
#
#HOTSPOT:AT!HSPWAUTOOFFACIDLETM=0
#HOTSPOT:AT!HSPWAUTOOFFBTIDLETM=0

############# LCD Dashboard #############
# Applies to: TBD
#
# SWI Ref: H051
#
# Description: Setup LCD dashboard screen
#
# Usage: HOTSPOT:AT!LCDDASHBOARD=<d1>,<d2>,...<dn>
#     dn = 1, Factory Test
#          2, Connect
#          3, Alert
#          4, Billing
#          5, Web Interface
#          6, About
#          7, Software
#          8, WPS
#          9, TRU-Install
#
#HOTSPOT:AT!LCDDASHBOARD=2,3,6,8

############ GPS Units ###############
# Applies to: TBD
#
# SWI Ref: H057
#
# Description: Setup GPS units
#
# Usage: HOTSPOT:AT!HSUSEMETRICSYS=<metric>
#     metric = 0, Imperial
#              1, Metric
#
#HOTSPOT:AT!HSUSEMETRICSYS=1

############# Maximum WiFi Client ##########
# Applies to: TBD
#
# SWI Ref: H052
#
# Description: Set maximum number of WiFi clients can be connected
#
# Usage: HOTSPOT:AT!HSWLANMAXCLIENTS=<Max>
#     Max = 0-10
#
#HOTSPOT:AT!HSWLANMAXCLIENTS=10

############## Device Key Lock ############
# Applies to: TBD
#
# SWI Ref: H053
#
# Description: Enable/Disable key lock on device
#
# Usage: HOTSPOT:AT!HSKEYLOCK=<value>
#      value = 0, Disable
#              1, Enable
#
#HOTSPOT:AT!HSKEYLOCK=1

############### uPnP ##################
# Applies to: TBD
#
# SWI Ref: N/A
#
# Description: Enable/Disable uPnP on device
#
# Usage: HOTSPOT:AT!HSUPNP=<value>
#      value = 0, Disable
#              1, Enable
#
#HOTSPOT:AT!HSUPNP=1

############## Default Language #############
# Applies to: TBD
#
# SWI Ref: H054
#
# Description: Device default language
#              Language defined in the /config/locales in the ROMFS
#
# Usage: HOTSPOT:AT!HSLANGDFLT="<value>"
#      value = en_US, fi_FI
#
#HOTSPOT:AT!HSLANGDFLT="en_US"

############# Language Selection on Screen ###########
# Applies to: TBD
#
# SWI Ref: H055
#
# Description: Set language selection screen on LCD
#
# Usage: HOTSPOT:AT!HSLANGSEL=<value>
#     value = 0 - Language has not been selected (Language selection screen will be enabled)
#             1 - Langauge has been selected
#
#HOTSPOT:AT!HSLANGSEL=0

############## Country Code #############
# Applies to: TBD
#
# SWI Ref: N/A
#
# Description: 2 letters country code as per ISO 3166-1 Alpha 2
#
# Usage: HOTSPOT:AT!HSWIFICOUNTRY="<value>"
#      value = US - United States
#              FR - France
#              JP - Japan
#
#              List of country code that support the use of WiFi channel 12 and 13:
#              AU, AT, BE, BM, IO, DK, FR, DE, GR, GG, VA, IE, IM, IT, JE, LI, KU, MC, NL, NZ, PT
#              SC, ES, SE, CH, GB, VG
#
#HOTSPOT:AT!HSWIFICOUNTRY="US"

############ Customer Settings #########
# Applies to: TBD
# 
# SWI Ref: N/A
#
# Description: Customization based on carrier
#
# Usage: HOTSPOT:AT!CUSTOM="CUSTOMER",<value>
#      value = 0 - Generic
#              1 - Softbank
#              2 - Telstra
#              3 - Bigpond
#              4 - ATT
#              5 - Rogers/Fido
#              6 - NetIndex
#              7 - DNA
#              8 - Bell
#              9 - Telus
#              
#HOTSPOT:AT!CUSTOM="CUSTOMER",0

############## Save Hotspot Settings #####
# Applies to: TBD
#
# Description: Save all settings
#
# Usage: HOTSPOT:AT!HSSAVEWLANCFG 
#
#HOTSPOT:AT!HSSAVEWLANCFG 

############## Clear Wi-Fi Connection Flag #####
# Applies to: TBD
#
# SWI Ref: N/A
#
# Description: Clear Wi-Fi connection flag
# 
# Usage: HOTSPOT:AT!HSWLANACTED=0
#
#HOTSPOT:AT!HSWLANACTED=0

###############################################################################
####### Final AT Commands                    ##################################  
####### Back up and Clean up - Do not Modify ##################################
###############################################################################

############## Clear the Error Log #######
# Applies to: All
#
FINAL:AT!ERR=0

############## Clear Black Box Log #######
# Applies to: TBD
#
FINAL:AT!BBCLEAR

############## Backup Data ###############
# Applies to: All
#
# Step 1, Backup RF Cal Data
#FINAL:AT!NVBACKUP=0

# Step 2, Backup Provisioning Data
#FINAL:AT!NVBACKUP=1

# Step 3, Backup User Data
#FINAL:AT!NVBACKUP=2

# Step 4, Check NV backup lists are complete
#FINAL:AT!NVBACKUPCHECK
#FINAL:AT!NVBACKUPCHECK?

###############################################################################
#
# Revision History:
#
# $Log$
#
#
#
#
###############################################################################

